# A simple color module I wrote for my projects
# Feel free to copy this script and use it for your own projects!


class Color:
    purple = '\033[95m'
    blue = '\033[94m'
    green = '\033[92m'
    yellow = '\033[93m'
    red = '\033[91m'
    white = '\033[0m'


class textType:
    bold = '\033[1m'
    underline = '\033[4m'



import re


def sort_by_name( l ):
    convert = lambda text: int(text) if text.isdigit() else text
    alphanum_key = lambda key: [ convert(c) for c in re.split('([0-9]+)', key) ]
    return sorted(l, key=alphanum_key)



#!/usr/bin/python

import os
import shutil
from setuptools import setup

if not os.path.exists('scripts'):
    os.makedirs('scripts')

try:
    shutil.copyfile('batch-rename.py', 'scripts/batch-rename')
except IOError:
    print("Could not copy batch-rename.py file. You can ignore this if you're installing with pip.")

setup(
    name='batch-rename',
    version='1.0.6',
    packages=['batch_renamer_cli'],
    scripts=['scripts/batch-rename'],
    install_requires=['colorama'],
    url='https://github.com/darko3/batch-renamer',
    download_url='https://github.com/darko3/batch-renamer/archive/1.0.6.tar.gz',
    keywords=['batch-renamer', 'files', 'python'],
    license='MIT',
    author='Girish Oemrawsingh',
    author_email='girish.oemrawsingh@protonmail.com',
    description='An easy to use python script for quickly renaming multiple files ending with incrementing numbers.'
)
